<?php

namespace Sitpak\Sittest\Policies;

use Litepie\User\Contracts\UserPolicy;
use Sitpak\Sittest\Models\Sittest;

class SittestPolicy
{

    /**
     * Determine if the given user can view the sittest.
     *
     * @param UserPolicy $user
     * @param Sittest $sittest
     *
     * @return bool
     */
    public function view(UserPolicy $user, Sittest $sittest)
    {
        if ($user->canDo('sittest.sittest.view') && $user->isAdmin()) {
            return true;
        }

        return $sittest->user_id == user_id() && $sittest->user_type == user_type();
    }

    /**
     * Determine if the given user can create a sittest.
     *
     * @param UserPolicy $user
     * @param Sittest $sittest
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('sittest.sittest.create');
    }

    /**
     * Determine if the given user can update the given sittest.
     *
     * @param UserPolicy $user
     * @param Sittest $sittest
     *
     * @return bool
     */
    public function update(UserPolicy $user, Sittest $sittest)
    {
        if ($user->canDo('sittest.sittest.edit') && $user->isAdmin()) {
            return true;
        }

        return $sittest->user_id == user_id() && $sittest->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given sittest.
     *
     * @param UserPolicy $user
     * @param Sittest $sittest
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Sittest $sittest)
    {
        return $sittest->user_id == user_id() && $sittest->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given sittest.
     *
     * @param UserPolicy $user
     * @param Sittest $sittest
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Sittest $sittest)
    {
        if ($user->canDo('sittest.sittest.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given sittest.
     *
     * @param UserPolicy $user
     * @param Sittest $sittest
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Sittest $sittest)
    {
        if ($user->canDo('sittest.sittest.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
