<?php

namespace Sitpak\Sittest\Providers;

use Illuminate\Support\ServiceProvider;

class SittestServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'sittest');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'sittest');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerSittest();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerSittest()
    {
        $this->app->bind('sittest', function($app) {
            return new Sittest($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Sittest', 'Lavalite\Sittest\Facades\Sittest');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('sitpak.sittest', function ($app) {
            return $this->app->make('Sitpak\Sittest\Sittest');
        });

                // Bind Sittest to repository
        $this->app->bind(
            'Sitpak\Sittest\Interfaces\SittestRepositoryInterface',
            \Sitpak\Sittest\Repositories\Eloquent\SittestRepository::class
        );

        $this->app->register(\Sitpak\Sittest\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Sitpak\Sittest\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and sittest's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/sittest.php', 'sittest'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeSittest::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['sitpak.sittest'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('sitpak/sittest.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/sittest')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/sittest')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
